from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class KzeroCls:
	"""Kzero commands group definition. 6 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("kzero", core, parent)

	@property
	def scfe(self):
		"""scfe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scfe'):
			from .Scfe import ScfeCls
			self._scfe = ScfeCls(self._core, self._cmd_group)
		return self._scfe

	@property
	def scft(self):
		"""scft commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scft'):
			from .Scft import ScftCls
			self._scft = ScftCls(self._core, self._cmd_group)
		return self._scft

	@property
	def scns(self):
		"""scns commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scns'):
			from .Scns import ScnsCls
			self._scns = ScnsCls(self._core, self._cmd_group)
		return self._scns

	@property
	def scot(self):
		"""scot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scot'):
			from .Scot import ScotCls
			self._scot = ScotCls(self._core, self._cmd_group)
		return self._scot

	@property
	def scst(self):
		"""scst commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scst'):
			from .Scst import ScstCls
			self._scst = ScstCls(self._core, self._cmd_group)
		return self._scst

	@property
	def sctt(self):
		"""sctt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sctt'):
			from .Sctt import ScttCls
			self._sctt = ScttCls(self._core, self._cmd_group)
		return self._sctt

	def clone(self) -> 'KzeroCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = KzeroCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import enums
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ClMappingCls:
	"""ClMapping commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clMapping", core, parent)

	def set(self, mapping: enums.AllocMapping, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:CLMapping \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.frame.bwPart.slot.allocation.clMapping.set(mapping = enums.AllocMapping.LC101, carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command selects the codeword to layer mapping. \n
			:param mapping: LC11 | LC21 | LC31 | LC41 | LC51 | LC61 | LC71 | LC81 | LC91 | LC101 | LC111 | LC121 | LC22 | LC32 | LC42 | LC52 | LC62 | LC72 | LC82 The availability of codeword to layer mappings depends on: • DM-RS configuration type (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Slot.Allocation.Dmrs.Ctype.set) • DM-RS length (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Slot.Allocation.Dmrs.Msymbol.Length.set) • Transmit precoding (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.TpRecoding.set)
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
		"""
		param = Conversions.enum_scalar_to_str(mapping, enums.AllocMapping)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		self._core.io.write(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:CLMapping {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default) -> enums.AllocMapping:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:CLMapping \n
		Snippet: value: enums.AllocMapping = driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.frame.bwPart.slot.allocation.clMapping.get(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command selects the codeword to layer mapping. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
			:return: mapping: LC11 | LC21 | LC31 | LC41 | LC51 | LC61 | LC71 | LC81 | LC91 | LC101 | LC111 | LC121 | LC22 | LC32 | LC42 | LC52 | LC62 | LC72 | LC82 The availability of codeword to layer mappings depends on: • DM-RS configuration type (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Slot.Allocation.Dmrs.Ctype.set) • DM-RS length (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Slot.Allocation.Dmrs.Msymbol.Length.set) • Transmit precoding (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.TpRecoding.set)"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		response = self._core.io.query_str(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:CLMapping?')
		return Conversions.str_to_scalar_enum(response, enums.AllocMapping)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 25 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	@property
	def avgPm(self):
		"""avgPm commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_avgPm'):
			from .AvgPm import AvgPmCls
			self._avgPm = AvgPmCls(self._core, self._cmd_group)
		return self._avgPm

	@property
	def maxPm(self):
		"""maxPm commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_maxPm'):
			from .MaxPm import MaxPmCls
			self._maxPm = MaxPmCls(self._core, self._cmd_group)
		return self._maxPm

	@property
	def rmsPm(self):
		"""rmsPm commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_rmsPm'):
			from .RmsPm import RmsPmCls
			self._rmsPm = RmsPmCls(self._core, self._cmd_group)
		return self._rmsPm

	@property
	def overshoot(self):
		"""overshoot commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_overshoot'):
			from .Overshoot import OvershootCls
			self._overshoot = OvershootCls(self._core, self._cmd_group)
		return self._overshoot

	@property
	def undershoot(self):
		"""undershoot commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_undershoot'):
			from .Undershoot import UndershootCls
			self._undershoot = UndershootCls(self._core, self._cmd_group)
		return self._undershoot

	def clone(self) -> 'PhaseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PhaseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ToleranceCls:
	"""Tolerance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tolerance", core, parent)

	def set(self, tolerance: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:STATes:TABLe:TOLerance \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.states.table.tolerance.set(tolerance = 1.0, window = repcap.Window.Default) \n
		No command help available \n
			:param tolerance: Unit: HZ
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(tolerance)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:STATes:TABLe:TOLerance {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def set(self, sample_rate: float, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:DIQ:SRATe \n
		Snippet: driver.applications.k10Xlte.inputPy.diq.symbolRate.set(sample_rate = 1.0, inputIx = repcap.InputIx.Default) \n
		This command specifies or queries the sample rate of the input signal from the optional 'Digital Baseband' interface. \n
			:param sample_rate: Range: 1 Hz to 20 GHz, Unit: HZ
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.decimal_value_to_str(sample_rate)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:DIQ:SRATe {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<ip>:DIQ:SRATe \n
		Snippet: value: float = driver.applications.k10Xlte.inputPy.diq.symbolRate.get(inputIx = repcap.InputIx.Default) \n
		This command specifies or queries the sample rate of the input signal from the optional 'Digital Baseband' interface. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: sample_rate: Range: 1 Hz to 20 GHz, Unit: HZ"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:DIQ:SRATe?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'SymbolRateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SymbolRateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:STABle:ITEM:MACCuracy:ALL \n
		Snippet: driver.applications.k18AmplifierEt.display.window.stable.item.maccuracy.all.set(state = False, window = repcap.Window.Default) \n
		This command adds and removes all modulation accuracy results from the statistics table. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:STABle:ITEM:MACCuracy:ALL {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CouplingCls:
	"""Coupling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coupling", core, parent)

	def set(self, input_coupling: enums.CouplingTypeA, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:COUPling \n
		Snippet: driver.applications.k70Vsa.inputPy.coupling.set(input_coupling = enums.CouplingTypeA.AC, inputIx = repcap.InputIx.Default) \n
		This command selects the coupling type of the RF input. The command is not available for measurements with the optional
		'Digital Baseband' interface. If an external frontend is active, the coupling is automatically set to AC. \n
			:param input_coupling: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(input_coupling, enums.CouplingTypeA)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:COUPling {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.CouplingTypeA:
		"""SCPI: INPut<ip>:COUPling \n
		Snippet: value: enums.CouplingTypeA = driver.applications.k70Vsa.inputPy.coupling.get(inputIx = repcap.InputIx.Default) \n
		This command selects the coupling type of the RF input. The command is not available for measurements with the optional
		'Digital Baseband' interface. If an external frontend is active, the coupling is automatically set to AC. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: input_coupling: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:COUPling?')
		return Conversions.str_to_scalar_enum(response, enums.CouplingTypeA)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GeneratorCls:
	"""Generator commands group definition. 11 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("generator", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def power(self):
		"""power commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def level(self):
		"""level commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def qerror(self):
		"""qerror commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_qerror'):
			from .Qerror import QerrorCls
			self._qerror = QerrorCls(self._core, self._cmd_group)
		return self._qerror

	@property
	def rfOutput(self):
		"""rfOutput commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfOutput'):
			from .RfOutput import RfOutputCls
			self._rfOutput = RfOutputCls(self._core, self._cmd_group)
		return self._rfOutput

	@property
	def control(self):
		"""control commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_control'):
			from .Control import ControlCls
			self._control = ControlCls(self._core, self._cmd_group)
		return self._control

	@property
	def settings(self):
		"""settings commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_settings'):
			from .Settings import SettingsCls
			self._settings = SettingsCls(self._core, self._cmd_group)
		return self._settings

	def clone(self) -> 'GeneratorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GeneratorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ThresholdCls:
	"""Threshold commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("threshold", core, parent)

	def set(self, value: float) -> None:
		"""SCPI: [SENSe]:MIXer:THReshold \n
		Snippet: driver.applications.k91Wlan.sense.mixer.threshold.set(value = 1.0) \n
		This command defines the maximum permissible level difference between test sweep and reference sweep to be corrected
		during automatic comparison (see [SENSe:]MIXer<x>:SIGNal) . \n
			:param value: numeric value Range: 0.1 dB to 100 dB, Unit: DB
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'SENSe:MIXer:THReshold {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:MIXer:THReshold \n
		Snippet: value: float = driver.applications.k91Wlan.sense.mixer.threshold.get() \n
		This command defines the maximum permissible level difference between test sweep and reference sweep to be corrected
		during automatic comparison (see [SENSe:]MIXer<x>:SIGNal) . \n
			:return: value: numeric value Range: 0.1 dB to 100 dB, Unit: DB"""
		response = self._core.io.query_str(f'SENSe:MIXer:THReshold?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrachCls:
	"""Prach commands group definition. 9 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prach", core, parent)

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	@property
	def lra(self):
		"""lra commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lra'):
			from .Lra import LraCls
			self._lra = LraCls(self._core, self._cmd_group)
		return self._lra

	@property
	def scs(self):
		"""scs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scs'):
			from .Scs import ScsCls
			self._scs = ScsCls(self._core, self._cmd_group)
		return self._scs

	@property
	def rbOffset(self):
		"""rbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbOffset'):
			from .RbOffset import RbOffsetCls
			self._rbOffset = RbOffsetCls(self._core, self._cmd_group)
		return self._rbOffset

	@property
	def rset(self):
		"""rset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rset'):
			from .Rset import RsetCls
			self._rset = RsetCls(self._core, self._cmd_group)
		return self._rset

	@property
	def rsequence(self):
		"""rsequence commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsequence'):
			from .Rsequence import RsequenceCls
			self._rsequence = RsequenceCls(self._core, self._cmd_group)
		return self._rsequence

	@property
	def zcZone(self):
		"""zcZone commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zcZone'):
			from .ZcZone import ZcZoneCls
			self._zcZone = ZcZoneCls(self._core, self._cmd_group)
		return self._zcZone

	@property
	def preamble(self):
		"""preamble commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_preamble'):
			from .Preamble import PreambleCls
			self._preamble = PreambleCls(self._core, self._cmd_group)
		return self._preamble

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	def clone(self) -> 'PrachCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PrachCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DetectionCls:
	"""Detection commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("detection", core, parent)

	def set(self, detection: enums.AutoManualMode, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:PLC:DETection \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.plc.detection.set(detection = enums.AutoManualMode.AUTO, carrierComponent = repcap.CarrierComponent.Default) \n
		This command turns automatic detection of the cell ID on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on auto demodulation (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Detection.set) .
			- Turn on transform precoding (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.TpRecoding.set) . \n
			:param detection: AUTO Auto detection of cell ID. MANual Manual entry of cell ID (method RsFsw.Applications.K10x_Lte.Configure.Lte.Uplink.Cc.Plc.Cid.set) .
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(detection, enums.AutoManualMode)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:PLC:DETection {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.AutoManualMode:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:PLC:DETection \n
		Snippet: value: enums.AutoManualMode = driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.plc.detection.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command turns automatic detection of the cell ID on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on auto demodulation (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Frame.BwPart.Detection.set) .
			- Turn on transform precoding (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.TpRecoding.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: detection: AUTO Auto detection of cell ID. MANual Manual entry of cell ID (method RsFsw.Applications.K10x_Lte.Configure.Lte.Uplink.Cc.Plc.Cid.set) ."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:PLC:DETection?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PresetCls:
	"""Preset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preset", core, parent)

	def set(self, channel_number: enums.ChannelNumber) -> None:
		"""SCPI: [SENSe]:CAPTure:PRESet \n
		Snippet: driver.applications.k149Uwb.sense.capture.preset.set(channel_number = enums.ChannelNumber.C0) \n
		Selects the HRP UWB Channel. \n
			:param channel_number: C0 | C1 | C2 | C3 | C4 | C5 | C6 | C7 | C8 | C9 | C10 | C11 | C12 | C13 | C14 | C15
		"""
		param = Conversions.enum_scalar_to_str(channel_number, enums.ChannelNumber)
		self._core.io.write(f'SENSe:CAPTure:PRESet {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ChannelNumber:
		"""SCPI: [SENSe]:CAPTure:PRESet \n
		Snippet: value: enums.ChannelNumber = driver.applications.k149Uwb.sense.capture.preset.get() \n
		Selects the HRP UWB Channel. \n
			:return: channel_number: C0 | C1 | C2 | C3 | C4 | C5 | C6 | C7 | C8 | C9 | C10 | C11 | C12 | C13 | C14 | C15"""
		response = self._core.io.query_str(f'SENSe:CAPTure:PRESet?')
		return Conversions.str_to_scalar_enum(response, enums.ChannelNumber)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FailCls:
	"""Fail commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fail", core, parent)

	def get(self) -> bool:
		"""SCPI: FETCh:SYNC:FAIL \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.fetch.sync.fail.get() \n
		This command queries the synchronization status. \n
			:return: state: 1 Synchronization was not successful. 0 Synchronization was successful."""
		response = self._core.io.query_str(f'FETCh:SYNC:FAIL?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FhDecadeCls:
	"""FhDecade commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fhDecade", core, parent)

	def set(self) -> None:
		"""SCPI: [SENSe]:SWEep:FHDecade \n
		Snippet: driver.applications.k40PhaseNoise.sense.sweep.fhDecade.set() \n
		This command stops the measurement in the current half decade and continues measuring in the subsequent half decade. \n
		"""
		self._core.io.write(f'SENSe:SWEep:FHDecade')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:SWEep:FHDecade \n
		Snippet: driver.applications.k40PhaseNoise.sense.sweep.fhDecade.set_with_opc() \n
		This command stops the measurement in the current half decade and continues measuring in the subsequent half decade. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:SWEep:FHDecade', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TruncateCls:
	"""Truncate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("truncate", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:PSPectrum:COLor:TRUNcate \n
		Snippet: driver.display.window.pspectrum.color.truncate.set(state = False, window = repcap.Window.Default) \n
		This command reduces the range of the color map of the persistence spectrum if there are no hits at the start or end of
		the value range. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:PSPectrum:COLor:TRUNcate {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: DISPlay[:WINDow<n>]:PSPectrum:COLor:TRUNcate \n
		Snippet: value: bool = driver.display.window.pspectrum.color.truncate.get(window = repcap.Window.Default) \n
		This command reduces the range of the color map of the persistence spectrum if there are no hits at the start or end of
		the value range. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:PSPectrum:COLor:TRUNcate?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def offset(self):
		"""offset commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def reference(self):
		"""reference commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reference'):
			from .Reference import ReferenceCls
			self._reference = ReferenceCls(self._core, self._cmd_group)
		return self._reference

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, frequency: List[float], level: List[float], window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:MASK:LOWer[:DATA] \n
		Snippet: driver.calculate.mask.lower.data.set(frequency = [1.1, 2.2, 3.3], level = [1.1, 2.2, 3.3], window = repcap.Window.Default) \n
		This command defines the shape of the lower frequency mask. Before making any changes to a frequency mask, you have to
		select one by name with method RsFsw.Calculate.Mask.Name.set. The unit of the power levels depends on method RsFsw.
		Calculate.Mask.Mode.set. For R&S FSW-K70, this command is query only. [N] pairs of numerical values. [N] is the number of
		data points the mask consists of. Each data point is defined by the frequency and the level. All values are separated by
		commas. Note that the data points have to be inside the current span. \n
			:param frequency: Frequency of the data point Unit: Hz
			:param level: Level of the data point Unit: DBM
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('frequency', frequency, DataType.FloatList, None), ArgSingle.as_open_list('level', level, DataType.FloatList, None))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:MASK:LOWer:DATA {param}'.rstrip())

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Response structure. Fields: \n
			- Frequency: List[float]: Frequency of the data point Unit: Hz
			- Level: List[float]: Level of the data point Unit: DBM"""
		__meta_args_list = [
			ArgStruct('Frequency', DataType.FloatList, None, False, True, 1),
			ArgStruct('Level', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency: List[float] = None
			self.Level: List[float] = None

	def get(self, window=repcap.Window.Default) -> DataStruct:
		"""SCPI: CALCulate<n>:MASK:LOWer[:DATA] \n
		Snippet: value: DataStruct = driver.calculate.mask.lower.data.get(window = repcap.Window.Default) \n
		This command defines the shape of the lower frequency mask. Before making any changes to a frequency mask, you have to
		select one by name with method RsFsw.Calculate.Mask.Name.set. The unit of the power levels depends on method RsFsw.
		Calculate.Mask.Mode.set. For R&S FSW-K70, this command is query only. [N] pairs of numerical values. [N] is the number of
		data points the mask consists of. Each data point is defined by the frequency and the level. All values are separated by
		commas. Note that the data points have to be inside the current span. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for DataStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:MASK:LOWer:DATA?', self.__class__.DataStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, mode: enums.ScalingMode) -> None:
		"""SCPI: [SENSe]:BWIDth:VIDeo:TYPE \n
		Snippet: driver.sense.bandwidth.video.typePy.set(mode = enums.ScalingMode.LINear) \n
		This command enables or disables the logarithmic amplifier in front of the video filter in the signal path. \n
			:param mode: LINear The logarithmic amplifier in front of the video filter is bypassed to process linear detector samples. LOGarithmic The logarithmic amplifier in front of the video filter is enabled to process logarithmic detector samples.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ScalingMode)
		self._core.io.write(f'SENSe:BWIDth:VIDeo:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ScalingMode:
		"""SCPI: [SENSe]:BWIDth:VIDeo:TYPE \n
		Snippet: value: enums.ScalingMode = driver.sense.bandwidth.video.typePy.get() \n
		This command enables or disables the logarithmic amplifier in front of the video filter in the signal path. \n
			:return: mode: LINear The logarithmic amplifier in front of the video filter is bypassed to process linear detector samples. LOGarithmic The logarithmic amplifier in front of the video filter is enabled to process logarithmic detector samples."""
		response = self._core.io.query_str(f'SENSe:BWIDth:VIDeo:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.ScalingMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AlignmentCls:
	"""Alignment commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alignment", core, parent)

	@property
	def falignment(self):
		"""falignment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_falignment'):
			from .Falignment import FalignmentCls
			self._falignment = FalignmentCls(self._core, self._cmd_group)
		return self._falignment

	@property
	def date(self):
		"""date commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_date'):
			from .Date import DateCls
			self._date = DateCls(self._core, self._cmd_group)
		return self._date

	@property
	def step(self):
		"""step commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_step'):
			from .Step import StepCls
			self._step = StepCls(self._core, self._cmd_group)
		return self._step

	def clone(self) -> 'AlignmentCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AlignmentCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def set(self, yaxis: enums.PulseFreqItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TRENd:FREQuency:Y \n
		Snippet: driver.applications.k6Pulse.calculate.trend.frequency.y.set(yaxis = enums.PulseFreqItems.CRATe, window = repcap.Window.Default) \n
		Configures the y-axis of the Parameter Trend result display.
		The x-axis is configured using the CALCulate<n>:TRENd:<GroupName>:X commands. \n
			:param yaxis: POINt | PPFRequency | RERRor | PERRor | DEViation | CRATe Pulse parameter to be displayed on the y-axis. For a description of the available parameters see 'Frequency parameters'. POINt Frequency at measurement point PPFRequency Pulse-Pulse Frequency Difference RERRor Frequency Error (RMS) PERRor Frequency Error (Peak) DEViation Frequency Deviation CRATe Chirp Rate
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(yaxis, enums.PulseFreqItems)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRENd:FREQuency:Y {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, externalGen=repcap.ExternalGen.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency:SWEep[:STATe] \n
		Snippet: driver.source.external.frequency.sweep.state.set(state = False, externalGen = repcap.ExternalGen.Nr1) \n
		Note that this command is maintained for compatibility reasons only. It is not required in new remote control programs.
		This command activates or deactivates the frequency sweep for the selected generator. This command is only valid if
		External Generator Control (R&S FSW-B10) is installed and active. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param externalGen: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.bool_to_str(state)
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		self._core.io.write(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:SWEep:STATe {param}')

	def get(self, externalGen=repcap.ExternalGen.Nr1) -> bool:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency:SWEep[:STATe] \n
		Snippet: value: bool = driver.source.external.frequency.sweep.state.get(externalGen = repcap.ExternalGen.Nr1) \n
		Note that this command is maintained for compatibility reasons only. It is not required in new remote control programs.
		This command activates or deactivates the frequency sweep for the selected generator. This command is only valid if
		External Generator Control (R&S FSW-B10) is installed and active. \n
			:param externalGen: optional repeated capability selector. Default value: Nr1
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:SWEep:STATe?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StringCls:
	"""String commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("string", core, parent)

	def set(self, string: str) -> None:
		"""SCPI: SYSTem:IDENtify[:STRing] \n
		Snippet: driver.system.identify.string.set(string = '1') \n
		This command defines the response to *IDN?. \n
			:param string: String containing the description of the instrument.
		"""
		param = Conversions.value_to_quoted_str(string)
		self._core.io.write(f'SYSTem:IDENtify:STRing {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:IDENtify[:STRing] \n
		Snippet: value: str = driver.system.identify.string.get() \n
		This command defines the response to *IDN?. \n
			:return: string: String containing the description of the instrument."""
		response = self._core.io.query_str(f'SYSTem:IDENtify:STRing?')
		return trim_str_response(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from .............Internal.Utilities import trim_str_response
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlotCls:
	"""Slot commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slot", core, parent)

	def set(self, slots: str, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:COPY:SLOT \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.slot.allocation.copy.slot.set(slots = '1', carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command copies a PDSCH allocation configuration to a specific set of slots.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Number of configurable slots > 1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Cslot.set) .
			- Select slot paste mode (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Slot.Allocation.Copy.Mode.set) . \n
			:param slots: String that contains a list of slots either as comma-separated list ('2,5,8') , a range ('3-5') or a combination of both ('2-5,8,10') .
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
		"""
		param = Conversions.value_to_quoted_str(slots)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:COPY:SLOT {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default) -> str:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:COPY:SLOT \n
		Snippet: value: str = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.slot.allocation.copy.slot.get(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command copies a PDSCH allocation configuration to a specific set of slots.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Number of configurable slots > 1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Cslot.set) .
			- Select slot paste mode (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Slot.Allocation.Copy.Mode.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
			:return: slots: String that contains a list of slots either as comma-separated list ('2,5,8') , a range ('3-5') or a combination of both ('2-5,8,10') ."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:COPY:SLOT?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CoefficientCls:
	"""Coefficient commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coefficient", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:LOAD:EQUalizer:FILTer:COEFficient \n
		Snippet: driver.applications.k18AmplifierEt.massMemory.load.equalizer.filterPy.coefficient.set(filename = '1') \n
		This command restores an equalizer filter that you have previously saved. \n
			:param filename: String containing the file name and location of the filter (csv file format) .
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'MMEMory:LOAD:EQUalizer:FILTer:COEFficient {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeleteCls:
	"""Delete commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("delete", core, parent)

	def set(self, standard: str, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer:STANdard:DELete \n
		Snippet: driver.applications.k14Xnr5G.calculate.marker.function.power.standard.delete.set(standard = '1', window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param standard: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.value_to_quoted_str(standard)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer:STANdard:DELete {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> str:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer:STANdard:DELete \n
		Snippet: value: str = driver.applications.k14Xnr5G.calculate.marker.function.power.standard.delete.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: standard: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer:STANdard:DELete?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PindexCls:
	"""Pindex commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pindex", core, parent)

	def set(self, prb_index: float) -> None:
		"""SCPI: CONFigure[:LTE]:DL:PINDex \n
		Snippet: driver.applications.k10Xlte.configure.lte.downlink.pindex.set(prb_index = 1.0) \n
		No command help available \n
			:param prb_index: No help available
		"""
		param = Conversions.decimal_value_to_str(prb_index)
		self._core.io.write(f'CONFigure:LTE:DL:PINDex {param}')

	def get(self) -> float:
		"""SCPI: CONFigure[:LTE]:DL:PINDex \n
		Snippet: value: float = driver.applications.k10Xlte.configure.lte.downlink.pindex.get() \n
		No command help available \n
			:return: prb_index: No help available"""
		response = self._core.io.query_str(f'CONFigure:LTE:DL:PINDex?')
		return Conversions.str_to_float(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DmrsCls:
	"""Dmrs commands group definition. 12 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dmrs", core, parent)

	@property
	def ap(self):
		"""ap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ap'):
			from .Ap import ApCls
			self._ap = ApCls(self._core, self._cmd_group)
		return self._ap

	@property
	def cgwd(self):
		"""cgwd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cgwd'):
			from .Cgwd import CgwdCls
			self._cgwd = CgwdCls(self._core, self._cmd_group)
		return self._cgwd

	@property
	def ctype(self):
		"""ctype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctype'):
			from .Ctype import CtypeCls
			self._ctype = CtypeCls(self._core, self._cmd_group)
		return self._ctype

	@property
	def msymbol(self):
		"""msymbol commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_msymbol'):
			from .Msymbol import MsymbolCls
			self._msymbol = MsymbolCls(self._core, self._cmd_group)
		return self._msymbol

	@property
	def mtype(self):
		"""mtype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtype'):
			from .Mtype import MtypeCls
			self._mtype = MtypeCls(self._core, self._cmd_group)
		return self._mtype

	@property
	def nscid(self):
		"""nscid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nscid'):
			from .Nscid import NscidCls
			self._nscid = NscidCls(self._core, self._cmd_group)
		return self._nscid

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def rst(self):
		"""rst commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rst'):
			from .Rst import RstCls
			self._rst = RstCls(self._core, self._cmd_group)
		return self._rst

	@property
	def sgeneration(self):
		"""sgeneration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sgeneration'):
			from .Sgeneration import SgenerationCls
			self._sgeneration = SgenerationCls(self._core, self._cmd_group)
		return self._sgeneration

	@property
	def sid(self):
		"""sid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sid'):
			from .Sid import SidCls
			self._sid = SidCls(self._core, self._cmd_group)
		return self._sid

	@property
	def tapos(self):
		"""tapos commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tapos'):
			from .Tapos import TaposCls
			self._tapos = TaposCls(self._core, self._cmd_group)
		return self._tapos

	def clone(self) -> 'DmrsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DmrsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	def set(self, state: bool, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:ATTenuation:AUTO \n
		Snippet: driver.applications.k18AmplifierEt.inputPy.attenuation.auto.set(state = False, inputIx = repcap.InputIx.Default) \n
		This command couples or decouples the attenuation to the reference level. Thus, when the reference level is changed, the
		R&S FSW determines the signal level for optimal internal data processing and sets the required attenuation accordingly. \n
			:param state: ON | OFF | 0 | 1
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.bool_to_str(state)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:ATTenuation:AUTO {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> bool:
		"""SCPI: INPut<ip>:ATTenuation:AUTO \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.inputPy.attenuation.auto.get(inputIx = repcap.InputIx.Default) \n
		This command couples or decouples the attenuation to the reference level. Thus, when the reference level is changed, the
		R&S FSW determines the signal level for optimal internal data processing and sets the required attenuation accordingly. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: state: ON | OFF | 0 | 1"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:ATTenuation:AUTO?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'AutoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AutoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PassedCls:
	"""Passed commands group definition. 4 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("passed", core, parent)

	@property
	def average(self):
		"""average commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_average'):
			from .Average import AverageCls
			self._average = AverageCls(self._core, self._cmd_group)
		return self._average

	@property
	def maximum(self):
		"""maximum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_maximum'):
			from .Maximum import MaximumCls
			self._maximum = MaximumCls(self._core, self._cmd_group)
		return self._maximum

	@property
	def minimum(self):
		"""minimum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_minimum'):
			from .Minimum import MinimumCls
			self._minimum = MinimumCls(self._core, self._cmd_group)
		return self._minimum

	def get(self, window=repcap.Window.Default) -> str:
		"""SCPI: FETCh<n>:SUMMary:PULSe:MASK:PASSed \n
		Snippet: value: str = driver.applications.k149Uwb.fetch.summary.pulse.mask.passed.get(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fetch')
			:return: result: numeric value"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'FETCh{window_cmd_val}:SUMMary:PULSe:MASK:PASSed?')
		return trim_str_response(response)

	def clone(self) -> 'PassedCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PassedCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScopeCls:
	"""Scope commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scope", core, parent)

	def set(self, frames: enums.FramesScope) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SCOPe \n
		Snippet: driver.sense.correction.fresponse.user.scope.set(frames = enums.FramesScope.ALL) \n
		Determines whether the frequency response correction settings are applied to all active measurement channels, or only the
		currently selected channel. \n
			:param frames: CHANnel | ALL CHANnel The frequency response correction settings are applied to the currently selected channel only. To select a channel, use method RsFsw.Instrument.Select.set. For a list of available channels, use method RsFsw.Instrument.ListPy.get_. ALL The frequency response correction settings are applied to all active measurement channels.
		"""
		param = Conversions.enum_scalar_to_str(frames, enums.FramesScope)
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:SCOPe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FramesScope:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SCOPe \n
		Snippet: value: enums.FramesScope = driver.sense.correction.fresponse.user.scope.get() \n
		Determines whether the frequency response correction settings are applied to all active measurement channels, or only the
		currently selected channel. \n
			:return: frames: CHANnel | ALL CHANnel The frequency response correction settings are applied to the currently selected channel only. To select a channel, use method RsFsw.Instrument.Select.set. For a list of available channels, use method RsFsw.Instrument.ListPy.get_. ALL The frequency response correction settings are applied to all active measurement channels."""
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:USER:SCOPe?')
		return Conversions.str_to_scalar_enum(response, enums.FramesScope)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AlternateCls:
	"""Alternate commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Channel, default value after init: Channel.Ch1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alternate", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_channel_get', 'repcap_channel_set', repcap.Channel.Ch1)

	def repcap_channel_set(self, channel: repcap.Channel) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Channel.Default
		Default value after init: Channel.Ch1"""
		self._cmd_group.set_repcap_enum_value(channel)

	def repcap_channel_get(self) -> repcap.Channel:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, spacing: float, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:ALTernate<ch> \n
		Snippet: driver.sense.power.achannel.spacing.alternate.set(spacing = 1.0, channel = repcap.Channel.Default) \n
		This command defines the distance from transmission channel to alternate channels. For MSR signals, this command defines
		the distance from the CF of the first Tx channel in the first sub block to the lower alternate channel. To configure the
		spacing for the upper alternate channel in asymmetrical configurations,
		use the [SENSe:]POWer:ACHannel:SPACing:UALTernate<ch> command. If you set the channel spacing for the first alternate
		channel, the R&S FSW adjusts the spacing of alternate channels of a lower order, but not the other way round (not for MSR
		signals) . The command works hierarchically: to set a distance from the transmission channel to the 2nd and 3rd alternate
		channel, you have to define a spacing for the 2nd alternate channel first. \n
			:param spacing: Range: 100 Hz to 2000 MHz, Unit: Hz
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Alternate')
		"""
		param = Conversions.decimal_value_to_str(spacing)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe:POWer:ACHannel:SPACing:ALTernate{channel_cmd_val} {param}')

	def get(self, channel=repcap.Channel.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:ALTernate<ch> \n
		Snippet: value: float = driver.sense.power.achannel.spacing.alternate.get(channel = repcap.Channel.Default) \n
		This command defines the distance from transmission channel to alternate channels. For MSR signals, this command defines
		the distance from the CF of the first Tx channel in the first sub block to the lower alternate channel. To configure the
		spacing for the upper alternate channel in asymmetrical configurations,
		use the [SENSe:]POWer:ACHannel:SPACing:UALTernate<ch> command. If you set the channel spacing for the first alternate
		channel, the R&S FSW adjusts the spacing of alternate channels of a lower order, but not the other way round (not for MSR
		signals) . The command works hierarchically: to set a distance from the transmission channel to the 2nd and 3rd alternate
		channel, you have to define a spacing for the 2nd alternate channel first. \n
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Alternate')
			:return: spacing: Range: 100 Hz to 2000 MHz, Unit: Hz"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SPACing:ALTernate{channel_cmd_val}?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'AlternateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AlternateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 6 total commands, 6 Subgroups, 0 group commands
	Repeated Capability: Instrument, default value after init: Instrument.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_instrument_get', 'repcap_instrument_set', repcap.Instrument.Nr1)

	def repcap_instrument_set(self, instrument: repcap.Instrument) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Instrument.Default
		Default value after init: Instrument.Nr1"""
		self._cmd_group.set_repcap_enum_value(instrument)

	def repcap_instrument_get(self) -> repcap.Instrument:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def bbPower(self):
		"""bbPower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bbPower'):
			from .BbPower import BbPowerCls
			self._bbPower = BbPowerCls(self._core, self._cmd_group)
		return self._bbPower

	@property
	def external(self):
		"""external commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_external'):
			from .External import ExternalCls
			self._external = ExternalCls(self._core, self._cmd_group)
		return self._external

	@property
	def ifPower(self):
		"""ifPower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ifPower'):
			from .IfPower import IfPowerCls
			self._ifPower = IfPowerCls(self._core, self._cmd_group)
		return self._ifPower

	@property
	def iqPower(self):
		"""iqPower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqPower'):
			from .IqPower import IqPowerCls
			self._iqPower = IqPowerCls(self._core, self._cmd_group)
		return self._iqPower

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def rfPower(self):
		"""rfPower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfPower'):
			from .RfPower import RfPowerCls
			self._rfPower = RfPowerCls(self._core, self._cmd_group)
		return self._rfPower

	def clone(self) -> 'LevelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LevelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpdateCls:
	"""Update commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("update", core, parent)

	def set(self) -> None:
		"""SCPI: CONFigure:GENerator:SETTings:UPDate \n
		Snippet: driver.applications.k18AmplifierEt.configure.generator.settings.update.set() \n
		This command updates the generator settings as defined within the R&S FSW-K18. Make sure to synchronize with *OPC?
		or *WAI to make sure that the command was successfully applied on the generator before sending the next command. \n
		"""
		self._core.io.write(f'CONFigure:GENerator:SETTings:UPDate')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:GENerator:SETTings:UPDate \n
		Snippet: driver.applications.k18AmplifierEt.configure.generator.settings.update.set_with_opc() \n
		This command updates the generator settings as defined within the R&S FSW-K18. Make sure to synchronize with *OPC?
		or *WAI to make sure that the command was successfully applied on the generator before sending the next command. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:GENerator:SETTings:UPDate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EgateCls:
	"""Egate commands group definition. 5 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("egate", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def nof(self):
		"""nof commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nof'):
			from .Nof import NofCls
			self._nof = NofCls(self._core, self._cmd_group)
		return self._nof

	@property
	def gap(self):
		"""gap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gap'):
			from .Gap import GapCls
			self._gap = GapCls(self._core, self._cmd_group)
		return self._gap

	def clone(self) -> 'EgateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EgateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, num_data_symbols: float) -> None:
		"""SCPI: [SENSe]:DEMod:FORMat:BANalyze:SYMBols:OFFSet \n
		Snippet: driver.applications.k91Wlan.sense.demod.formatPy.banalyze.symbols.offset.set(num_data_symbols = 1.0) \n
		For IEEE 802.11a, ac, g (OFDM) , j, n, p signals only: This command specifies the number of data symbols from the start
		of each PPDU that are to be skipped before symbols take part in analysis. \n
			:param num_data_symbols: integer Range: 0 to 10000
		"""
		param = Conversions.decimal_value_to_str(num_data_symbols)
		self._core.io.write(f'SENSe:DEMod:FORMat:BANalyze:SYMBols:OFFSet {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DEMod:FORMat:BANalyze:SYMBols:OFFSet \n
		Snippet: value: float = driver.applications.k91Wlan.sense.demod.formatPy.banalyze.symbols.offset.get() \n
		For IEEE 802.11a, ac, g (OFDM) , j, n, p signals only: This command specifies the number of data symbols from the start
		of each PPDU that are to be skipped before symbols take part in analysis. \n
			:return: num_data_symbols: integer Range: 0 to 10000"""
		response = self._core.io.query_str(f'SENSe:DEMod:FORMat:BANalyze:SYMBols:OFFSet?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StopCls:
	"""Stop commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stop", core, parent)

	def set(self, offset_frequency: float, window=repcap.Window.Default, userRange=repcap.UserRange.Default) -> None:
		"""SCPI: CALCulate<n>:EVALuation:USER<res>:STOP \n
		Snippet: driver.applications.k40PhaseNoise.calculate.evaluation.user.stop.set(offset_frequency = 1.0, window = repcap.Window.Default, userRange = repcap.UserRange.Default) \n
		This command defines the end point of a custom residual noise calculation range. Before you can use the command, you have
		to assign the user range to a trace with method RsFsw.Applications.K40_PhaseNoise.Calculate.Evaluation.User.Trace.set. \n
			:param offset_frequency: The minimum offset is 1 Hz. The maximum offset depends on the hardware you are using. Unit: HZ
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param userRange: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.decimal_value_to_str(offset_frequency)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		userRange_cmd_val = self._cmd_group.get_repcap_cmd_value(userRange, repcap.UserRange)
		self._core.io.write(f'CALCulate{window_cmd_val}:EVALuation:USER{userRange_cmd_val}:STOP {param}')

	def get(self, window=repcap.Window.Default, userRange=repcap.UserRange.Default) -> float:
		"""SCPI: CALCulate<n>:EVALuation:USER<res>:STOP \n
		Snippet: value: float = driver.applications.k40PhaseNoise.calculate.evaluation.user.stop.get(window = repcap.Window.Default, userRange = repcap.UserRange.Default) \n
		This command defines the end point of a custom residual noise calculation range. Before you can use the command, you have
		to assign the user range to a trace with method RsFsw.Applications.K40_PhaseNoise.Calculate.Evaluation.User.Trace.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param userRange: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: offset_frequency: The minimum offset is 1 Hz. The maximum offset depends on the hardware you are using. Unit: HZ"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		userRange_cmd_val = self._cmd_group.get_repcap_cmd_value(userRange, repcap.UserRange)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:EVALuation:USER{userRange_cmd_val}:STOP?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Trace, default value after init: Trace.Tr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_trace_get', 'repcap_trace_set', repcap.Trace.Tr1)

	def repcap_trace_set(self, trace: repcap.Trace) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Trace.Default
		Default value after init: Trace.Tr1"""
		self._cmd_group.set_repcap_enum_value(trace)

	def repcap_trace_get(self) -> repcap.Trace:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def get(self, probability: enums.Probability, window=repcap.Window.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: CALCulate<n>:STATistics:CCDF:X<t> \n
		Snippet: value: float = driver.applications.k14Xnr5G.calculate.statistics.cumulativeDistribFnc.x.get(probability = enums.Probability.P0_01, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command queries the results of the CCDF. \n
			:param probability: P0_01 Level value for 0.01 % probability P0_1 Level value for 0.1 % probability P1 P1: Level value for 1 % probability P10 Level value for 10 % probability
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'X')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(probability, enums.Probability)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:STATistics:CCDF:X{trace_cmd_val}? {param}')
		return Conversions.str_to_float(response)

	def clone(self) -> 'XCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = XCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: enums.DspreadK91) -> None:
		"""SCPI: [SENSe]:DEMod:INTerpolate:WIENer:DSPRead:STATe \n
		Snippet: driver.applications.k91Wlan.sense.demod.interpolate.wiener.dspread.state.set(state = enums.DspreadK91.MANual) \n
		Defines whether the Wiener relative delay spread is disabled or defined manually. This command is only available for
		standards IEEE 802.11ax, be and only for [SENSe:]DEMod:INTerpolateWiener. \n
			:param state: OFF | MANual OFF No delay spread is used. MAN The value is determined manually, using [SENSe:]DEMod:INTerpolate:WIENer:DSPRead.
		"""
		param = Conversions.enum_scalar_to_str(state, enums.DspreadK91)
		self._core.io.write(f'SENSe:DEMod:INTerpolate:WIENer:DSPRead:STATe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DspreadK91:
		"""SCPI: [SENSe]:DEMod:INTerpolate:WIENer:DSPRead:STATe \n
		Snippet: value: enums.DspreadK91 = driver.applications.k91Wlan.sense.demod.interpolate.wiener.dspread.state.get() \n
		Defines whether the Wiener relative delay spread is disabled or defined manually. This command is only available for
		standards IEEE 802.11ax, be and only for [SENSe:]DEMod:INTerpolateWiener. \n
			:return: state: OFF | MANual OFF No delay spread is used. MAN The value is determined manually, using [SENSe:]DEMod:INTerpolate:WIENer:DSPRead."""
		response = self._core.io.query_str(f'SENSe:DEMod:INTerpolate:WIENer:DSPRead:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.DspreadK91)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ChannelCls:
	"""Channel commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Channel, default value after init: Channel.Ch1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("channel", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_channel_get', 'repcap_channel_set', repcap.Channel.Ch1)

	def repcap_channel_set(self, channel: repcap.Channel) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Channel.Default
		Default value after init: Channel.Ch1"""
		self._cmd_group.set_repcap_enum_value(channel)

	def repcap_channel_get(self) -> repcap.Channel:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, standard: enums.TechnologyStandardA, subBlock=repcap.SubBlock.Default, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:TECHnology[:CHANnel<ch>] \n
		Snippet: driver.sense.power.achannel.sblock.technology.channel.set(standard = enums.TechnologyStandardA.GSM, subBlock = repcap.SubBlock.Default, channel = repcap.Channel.Default) \n
		This command defines the technology used for transmission by the specified MSR Tx channel. This command is for MSR
		signals only (see method RsFsw.Calculate.Marker.Function.Power.preset) . For details on MSR signals see 'Measurement on
		multi-standard radio (MSR) signals'. \n
			:param standard: Technology used for transmission GSM Transmission according to GSM standard WCDMa Transmission according to W-CDMA standard LTE_1_40 | LTE_3_00 | LTE_5_00 | LTE_10_00 | LTE_15_00 | LTE_20_00 Transmission according to LTE standard for different channel bandwidths NR5G_fr1_5 | NR5G_fr1_10 | NR5G_fr1_15 | NR5G_fr1_20 | NR5G_fr1_25 | NR5G_fr1_30 | NR5G_fr1_40 | NR5G_fr1_50 | NR5G_fr1_60 | NR5G_fr1_70 | NR5G_fr1_80 | NR5G_fr1_90 | NR5G_fr1_100 | NR5G_fr2_50 | NR5G_fr2_100 | NR5G_fr2_200 | NR5G_fr2_400 Transmission according to new radio 5G standard USER User-defined transmission; no automatic preconfiguration possible
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Channel')
		"""
		param = Conversions.enum_scalar_to_str(standard, enums.TechnologyStandardA)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:TECHnology:CHANnel{channel_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, subBlock=repcap.SubBlock.Default, channel=repcap.Channel.Default) -> enums.TechnologyStandardA:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:TECHnology[:CHANnel<ch>] \n
		Snippet: value: enums.TechnologyStandardA = driver.sense.power.achannel.sblock.technology.channel.get(subBlock = repcap.SubBlock.Default, channel = repcap.Channel.Default) \n
		This command defines the technology used for transmission by the specified MSR Tx channel. This command is for MSR
		signals only (see method RsFsw.Calculate.Marker.Function.Power.preset) . For details on MSR signals see 'Measurement on
		multi-standard radio (MSR) signals'. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Channel')
			:return: standard: Technology used for transmission GSM Transmission according to GSM standard WCDMa Transmission according to W-CDMA standard LTE_1_40 | LTE_3_00 | LTE_5_00 | LTE_10_00 | LTE_15_00 | LTE_20_00 Transmission according to LTE standard for different channel bandwidths NR5G_fr1_5 | NR5G_fr1_10 | NR5G_fr1_15 | NR5G_fr1_20 | NR5G_fr1_25 | NR5G_fr1_30 | NR5G_fr1_40 | NR5G_fr1_50 | NR5G_fr1_60 | NR5G_fr1_70 | NR5G_fr1_80 | NR5G_fr1_90 | NR5G_fr1_100 | NR5G_fr2_50 | NR5G_fr2_100 | NR5G_fr2_200 | NR5G_fr2_400 Transmission according to new radio 5G standard USER User-defined transmission; no automatic preconfiguration possible"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:TECHnology:CHANnel{channel_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.TechnologyStandardA)

	def clone(self) -> 'ChannelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ChannelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CouplingCls:
	"""Coupling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coupling", core, parent)

	def set(self, state: bool, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:DIQ:RANGe:COUPling \n
		Snippet: driver.applications.k70Vsa.inputPy.diq.range.coupling.set(state = False, inputIx = repcap.InputIx.Default) \n
		If enabled, the reference level for digital input is adjusted to the full scale level automatically if the full scale
		level changes. This command is only available if the optional 'Digital Baseband' interface is installed. \n
			:param state: ON | OFF | 1 | 0
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.bool_to_str(state)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:DIQ:RANGe:COUPling {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> bool:
		"""SCPI: INPut<ip>:DIQ:RANGe:COUPling \n
		Snippet: value: bool = driver.applications.k70Vsa.inputPy.diq.range.coupling.get(inputIx = repcap.InputIx.Default) \n
		If enabled, the reference level for digital input is adjusted to the full scale level automatically if the full scale
		level changes. This command is only available if the optional 'Digital Baseband' interface is installed. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: state: ON | OFF | 1 | 0"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:DIQ:RANGe:COUPling?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RefSignalCls:
	"""RefSignal commands group definition. 27 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("refSignal", core, parent)

	@property
	def cgw(self):
		"""cgw commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_cgw'):
			from .Cgw import CgwCls
			self._cgw = CgwCls(self._core, self._cmd_group)
		return self._cgw

	@property
	def cwf(self):
		"""cwf commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_cwf'):
			from .Cwf import CwfCls
			self._cwf = CwfCls(self._core, self._cmd_group)
		return self._cwf

	@property
	def gos(self):
		"""gos commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_gos'):
			from .Gos import GosCls
			self._gos = GosCls(self._core, self._cmd_group)
		return self._gos

	@property
	def segment(self):
		"""segment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_segment'):
			from .Segment import SegmentCls
			self._segment = SegmentCls(self._core, self._cmd_group)
		return self._segment

	@property
	def sinfo(self):
		"""sinfo commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_sinfo'):
			from .Sinfo import SinfoCls
			self._sinfo = SinfoCls(self._core, self._cmd_group)
		return self._sinfo

	def clone(self) -> 'RefSignalCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RefSignalCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CabwCls:
	"""Cabw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cabw", core, parent)

	def set(self, bandwidth: enums.BandwidthLteA) -> None:
		"""SCPI: CONFigure[:LTE]:UL:CABW \n
		Snippet: driver.applications.k10Xlte.configure.lte.uplink.cabw.set(bandwidth = enums.BandwidthLteA.B1010) \n
		This command selects the channel bandwidth(s) of the carriers in MC ACLR measurements. \n
			:param bandwidth: B510 First carrier: 5 MHz, second carrier: 10 MHz bandwidth. B520 First carrier: 5 MHz, second carrier: 20 MHz bandwidth. B1010 First carrier: 10 MHz, second carrier: 10 MHz bandwidth. B1015 First carrier: 10 MHz, second carrier: 15 MHz bandwidth. B1020 First carrier: 10 MHz, second carrier: 20 MHz bandwidth. B1515 First carrier: 15 MHz, second carrier: 15 MHz bandwidth. B1520 First carrier: 15 MHz, second carrier: 20 MHz bandwidth. B2020 First carrier: 20 MHz, second carrier: 20 MHz bandwidth. USER Custom combination of bandwidths. Define the bandwidths of both carriers with method RsFsw.Applications.K10x_Lte.Configure.Lte.Uplink.Cc.Bw.set.
		"""
		param = Conversions.enum_scalar_to_str(bandwidth, enums.BandwidthLteA)
		self._core.io.write(f'CONFigure:LTE:UL:CABW {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.BandwidthLteA:
		"""SCPI: CONFigure[:LTE]:UL:CABW \n
		Snippet: value: enums.BandwidthLteA = driver.applications.k10Xlte.configure.lte.uplink.cabw.get() \n
		This command selects the channel bandwidth(s) of the carriers in MC ACLR measurements. \n
			:return: bandwidth: B510 First carrier: 5 MHz, second carrier: 10 MHz bandwidth. B520 First carrier: 5 MHz, second carrier: 20 MHz bandwidth. B1010 First carrier: 10 MHz, second carrier: 10 MHz bandwidth. B1015 First carrier: 10 MHz, second carrier: 15 MHz bandwidth. B1020 First carrier: 10 MHz, second carrier: 20 MHz bandwidth. B1515 First carrier: 15 MHz, second carrier: 15 MHz bandwidth. B1520 First carrier: 15 MHz, second carrier: 20 MHz bandwidth. B2020 First carrier: 20 MHz, second carrier: 20 MHz bandwidth. USER Custom combination of bandwidths. Define the bandwidths of both carriers with method RsFsw.Applications.K10x_Lte.Configure.Lte.Uplink.Cc.Bw.set."""
		response = self._core.io.query_str(f'CONFigure:LTE:UL:CABW?')
		return Conversions.str_to_scalar_enum(response, enums.BandwidthLteA)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlotsCls:
	"""Slots commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slots", core, parent)

	def set(self, slots: float) -> None:
		"""SCPI: [SENSe]:ADJust:EVM:SLOTs \n
		Snippet: driver.applications.k14Xnr5G.sense.adjust.evm.slots.set(slots = 1.0) \n
		This command selects the number of slots to be used during the auto EVM routine.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select manual automatic measurement time mode ([SENSe:]ADJust:CONFigure:LEVel:DURation:MODE) .
			- Define an appropriate automatic measurement time ([SENSe:]ADJust:CONFigure:LEVel:DURation) . \n
			:param slots: No help available
		"""
		param = Conversions.decimal_value_to_str(slots)
		self._core.io.write(f'SENSe:ADJust:EVM:SLOTs {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADJust:EVM:SLOTs \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.adjust.evm.slots.get() \n
		This command selects the number of slots to be used during the auto EVM routine.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select manual automatic measurement time mode ([SENSe:]ADJust:CONFigure:LEVel:DURation:MODE) .
			- Define an appropriate automatic measurement time ([SENSe:]ADJust:CONFigure:LEVel:DURation) . \n
			:return: slots: No help available"""
		response = self._core.io.query_str(f'SENSe:ADJust:EVM:SLOTs?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolCls:
	"""Symbol commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbol", core, parent)

	def set(self, style: enums.TraceStyleSymbol, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:SYMBol \n
		Snippet: driver.display.window.subwindow.trace.symbol.set(style = enums.TraceStyleSymbol.DOTS, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command sets the display style of the persistence spectrum. \n
			:param style: DOTS Displays the data as dots. The result is a persistence spectrum made up out of dots. VECTor Interpolates the measurement points. The result is an uninterrupted persistence spectrum.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(style, enums.TraceStyleSymbol)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:SYMBol {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> enums.TraceStyleSymbol:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:SYMBol \n
		Snippet: value: enums.TraceStyleSymbol = driver.display.window.subwindow.trace.symbol.get(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command sets the display style of the persistence spectrum. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: style: DOTS Displays the data as dots. The result is a persistence spectrum made up out of dots. VECTor Interpolates the measurement points. The result is an uninterrupted persistence spectrum."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:SYMBol?')
		return Conversions.str_to_scalar_enum(response, enums.TraceStyleSymbol)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HoldoffCls:
	"""Holdoff commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("holdoff", core, parent)

	def set(self, if_power_holdoff: float, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: TRIGger<tp>[:SEQuence]:BBPower:HOLDoff \n
		Snippet: driver.applications.k70Vsa.trigger.sequence.bbPower.holdoff.set(if_power_holdoff = 1.0, triggerPort = repcap.TriggerPort.Default) \n
		This command defines the holding time before the baseband power trigger event. The command requires the optional 'Digital
		Baseband' interface or the optional 'Analog Baseband' interface. Note that this command is maintained for compatibility
		reasons only. Use the method RsFsw.Applications.K10x_Lte.Trigger.Sequence.IfPower.Holdoff.set command for new remote
		control programs. \n
			:param if_power_holdoff: Range: 150 ns to 1000 s, Unit: S
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.decimal_value_to_str(if_power_holdoff)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'TRIGger{triggerPort_cmd_val}:SEQuence:BBPower:HOLDoff {param}')

	def get(self, triggerPort=repcap.TriggerPort.Default) -> float:
		"""SCPI: TRIGger<tp>[:SEQuence]:BBPower:HOLDoff \n
		Snippet: value: float = driver.applications.k70Vsa.trigger.sequence.bbPower.holdoff.get(triggerPort = repcap.TriggerPort.Default) \n
		This command defines the holding time before the baseband power trigger event. The command requires the optional 'Digital
		Baseband' interface or the optional 'Analog Baseband' interface. Note that this command is maintained for compatibility
		reasons only. Use the method RsFsw.Applications.K10x_Lte.Trigger.Sequence.IfPower.Holdoff.set command for new remote
		control programs. \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: if_power_holdoff: No help available"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'TRIGger{triggerPort_cmd_val}:SEQuence:BBPower:HOLDoff?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImpedanceCls:
	"""Impedance commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("impedance", core, parent)

	@property
	def ptype(self):
		"""ptype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ptype'):
			from .Ptype import PtypeCls
			self._ptype = PtypeCls(self._core, self._cmd_group)
		return self._ptype

	def set(self, impedance: float, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:IMPedance \n
		Snippet: driver.applications.k70Vsa.inputPy.impedance.set(impedance = 1.0, inputIx = repcap.InputIx.Default) \n
		This command selects the nominal input impedance of the RF input. In some applications, only 50 Ω are supported.
		The command is not available for measurements with the optional 'Digital Baseband' interface. \n
			:param impedance: 50 | 75 numeric value User-defined impedance from 50 Ohm to 100000000 Ohm (=100 MOhm) User-defined values are only available for the Spectrum application, the I/Q Analyzer, and some optional applications. (In MSRA mode, primary only) Unit: OHM
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.decimal_value_to_str(impedance)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:IMPedance {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<ip>:IMPedance \n
		Snippet: value: float = driver.applications.k70Vsa.inputPy.impedance.get(inputIx = repcap.InputIx.Default) \n
		This command selects the nominal input impedance of the RF input. In some applications, only 50 Ω are supported.
		The command is not available for measurements with the optional 'Digital Baseband' interface. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: impedance: 50 | 75 numeric value User-defined impedance from 50 Ohm to 100000000 Ohm (=100 MOhm) User-defined values are only available for the Spectrum application, the I/Q Analyzer, and some optional applications. (In MSRA mode, primary only) Unit: OHM"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IMPedance?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'ImpedanceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ImpedanceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 17 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	@property
	def all(self):
		"""all commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def deviation(self):
		"""deviation commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_deviation'):
			from .Deviation import DeviationCls
			self._deviation = DeviationCls(self._core, self._cmd_group)
		return self._deviation

	@property
	def perror(self):
		"""perror commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_perror'):
			from .Perror import PerrorCls
			self._perror = PerrorCls(self._core, self._cmd_group)
		return self._perror

	@property
	def point(self):
		"""point commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_point'):
			from .Point import PointCls
			self._point = PointCls(self._core, self._cmd_group)
		return self._point

	@property
	def ppPhase(self):
		"""ppPhase commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_ppPhase'):
			from .PpPhase import PpPhaseCls
			self._ppPhase = PpPhaseCls(self._core, self._cmd_group)
		return self._ppPhase

	@property
	def rerror(self):
		"""rerror commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_rerror'):
			from .Rerror import RerrorCls
			self._rerror = RerrorCls(self._core, self._cmd_group)
		return self._rerror

	def clone(self) -> 'PhaseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PhaseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CompatibleCls:
	"""Compatible commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("compatible", core, parent)

	def set(self, mode: enums.CompatibilityMode) -> None:
		"""SCPI: SYSTem:COMPatible \n
		Snippet: driver.system.compatible.set(mode = enums.CompatibilityMode.ATT) \n
		This command enables compatibility to other spectrum and signal analyzers by R&S. Compatibility is necessary, for example,
		regarding the number of sweep points. Note that this command is maintained for compatibility reasons only. Use the method
		RsFsw.System.Language.set command for new remote control programs (see method RsFsw.System.Language.set) . \n
			:param mode: DEFault | FSU | FSP | FSQ | FSV
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.CompatibilityMode)
		self._core.io.write(f'SYSTem:COMPatible {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.CompatibilityMode:
		"""SCPI: SYSTem:COMPatible \n
		Snippet: value: enums.CompatibilityMode = driver.system.compatible.get() \n
		This command enables compatibility to other spectrum and signal analyzers by R&S. Compatibility is necessary, for example,
		regarding the number of sweep points. Note that this command is maintained for compatibility reasons only. Use the method
		RsFsw.System.Language.set command for new remote control programs (see method RsFsw.System.Language.set) . \n
			:return: mode: DEFault | FSU | FSP | FSQ | FSV"""
		response = self._core.io.query_str(f'SYSTem:COMPatible?')
		return Conversions.str_to_scalar_enum(response, enums.CompatibilityMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LogoCls:
	"""Logo commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("logo", core, parent)

	@property
	def control(self):
		"""control commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_control'):
			from .Control import ControlCls
			self._control = ControlCls(self._core, self._cmd_group)
		return self._control

	def set(self, filename: str) -> None:
		"""SCPI: HCOPy:TREPort:ITEM:LOGO \n
		Snippet: driver.hardCopy.treport.item.logo.set(filename = '1') \n
		No command help available \n
			:param filename: String containing the location and name of the picture. You can use the following file types: bmp, jpg, png, gif, emf or wmf format.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'HCOPy:TREPort:ITEM:LOGO {param}')

	def get(self) -> str:
		"""SCPI: HCOPy:TREPort:ITEM:LOGO \n
		Snippet: value: str = driver.hardCopy.treport.item.logo.get() \n
		No command help available \n
			:return: filename: String containing the location and name of the picture. You can use the following file types: bmp, jpg, png, gif, emf or wmf format."""
		response = self._core.io.query_str(f'HCOPy:TREPort:ITEM:LOGO?')
		return trim_str_response(response)

	def clone(self) -> 'LogoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LogoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, sts_format: enums.StsFormat) -> None:
		"""SCPI: [SENSe]:DEMod:STS:FORMat \n
		Snippet: driver.applications.k149Uwb.sense.demod.sts.formatPy.set(sts_format = enums.StsFormat.F0) \n
		Sets the STS format. \n
			:param sts_format: F0 | F1 | F2 | F3
		"""
		param = Conversions.enum_scalar_to_str(sts_format, enums.StsFormat)
		self._core.io.write(f'SENSe:DEMod:STS:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.StsFormat:
		"""SCPI: [SENSe]:DEMod:STS:FORMat \n
		Snippet: value: enums.StsFormat = driver.applications.k149Uwb.sense.demod.sts.formatPy.get() \n
		Sets the STS format. \n
			:return: sts_format: F0 | F1 | F2 | F3"""
		response = self._core.io.query_str(f'SENSe:DEMod:STS:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.StsFormat)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LinkCls:
	"""Link commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	def set(self, display_type: enums.DisplayType, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:LINK \n
		Snippet: driver.calculate.marker.link.set(display_type = enums.DisplayType.BOTH, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		Links the specified marker in all displays of the specified type. \n
			:param display_type: TIME | SPECtrum | BOTH | NONE TIME Links the markers in all time domain diagrams SPECtrum Links the markers in all AF Spectrum displays BOTH Links the markers both in the time domain diagrams and in the AF Spectrum displays NONE Markers are not linked.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.enum_scalar_to_str(display_type, enums.DisplayType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:LINK {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> enums.DisplayType:
		"""SCPI: CALCulate<n>:MARKer<m>:LINK \n
		Snippet: value: enums.DisplayType = driver.calculate.marker.link.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		Links the specified marker in all displays of the specified type. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: display_type: TIME | SPECtrum | BOTH | NONE TIME Links the markers in all time domain diagrams SPECtrum Links the markers in all AF Spectrum displays BOTH Links the markers both in the time domain diagrams and in the AF Spectrum displays NONE Markers are not linked."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.DisplayType)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinCls:
	"""Min commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("min", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:MPOWer:RESult:MIN \n
		Snippet: value: float = driver.sense.mpower.result.min.get() \n
		This command queries the lowest pulse power that has been measured during a pulse power measurement. If there are no
		results, the command returns an error. \n
			:return: pulse_power: Lowest power level of the pulse power measurement. The unit is dBm."""
		response = self._core.io.query_str(f'SENSe:MPOWer:RESult:MIN?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PlciCls:
	"""Plci commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("plci", core, parent)

	@property
	def cid(self):
		"""cid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cid'):
			from .Cid import CidCls
			self._cid = CidCls(self._core, self._cmd_group)
		return self._cid

	@property
	def cidGroup(self):
		"""cidGroup commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cidGroup'):
			from .CidGroup import CidGroupCls
			self._cidGroup = CidGroupCls(self._core, self._cmd_group)
		return self._cidGroup

	@property
	def plid(self):
		"""plid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_plid'):
			from .Plid import PlidCls
			self._plid = PlidCls(self._core, self._cmd_group)
		return self._plid

	def clone(self) -> 'PlciCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PlciCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RlengthCls:
	"""Rlength commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rlength", core, parent)

	def get(self) -> float:
		"""SCPI: TRACe:IQ:SYNC:RLENgth \n
		Snippet: value: float = driver.applications.k18AmplifierEt.trace.iq.sync.rlength.get() \n
		Returns the sweep length or capture length at the current sample rate. \n
			:return: samples: numeric value"""
		response = self._core.io.query_str(f'TRACe:IQ:SYNC:RLENgth?')
		return Conversions.str_to_float(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import enums
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScramblingCls:
	"""Scrambling commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scrambling", core, parent)

	@property
	def dsid(self):
		"""dsid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dsid'):
			from .Dsid import DsidCls
			self._dsid = DsidCls(self._core, self._cmd_group)
		return self._dsid

	def set(self, method: enums.PdschSeqGenMethod, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:SCRambling \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.slot.allocation.scrambling.set(method = enums.PdschSeqGenMethod.DSID, carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command selects the PDSCH scrambling method. \n
			:param method: DSID Sequence generation based on a pseudo-random seed value. NIDCell Sequence generation based on the cell ID.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
		"""
		param = Conversions.enum_scalar_to_str(method, enums.PdschSeqGenMethod)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:SCRambling {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, slot=repcap.Slot.Default, allocation=repcap.Allocation.Default) -> enums.PdschSeqGenMethod:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SLOT<sl>:ALLocation<al>:SCRambling \n
		Snippet: value: enums.PdschSeqGenMethod = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.slot.allocation.scrambling.get(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, slot = repcap.Slot.Default, allocation = repcap.Allocation.Default) \n
		This command selects the PDSCH scrambling method. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param slot: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocation: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Allocation')
			:return: method: DSID Sequence generation based on a pseudo-random seed value. NIDCell Sequence generation based on the cell ID."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		allocation_cmd_val = self._cmd_group.get_repcap_cmd_value(allocation, repcap.Allocation)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SLOT{slot_cmd_val}:ALLocation{allocation_cmd_val}:SCRambling?')
		return Conversions.str_to_scalar_enum(response, enums.PdschSeqGenMethod)

	def clone(self) -> 'ScramblingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ScramblingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PreambleCls:
	"""Preamble commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preamble", core, parent)

	def set(self, mode: enums.PreambeTrackMode) -> None:
		"""SCPI: [SENSe]:TRACking:PREamble \n
		Snippet: driver.applications.k91Wlan.sense.tracking.preamble.set(mode = enums.PreambeTrackMode.PAYLoad) \n
		Defines which results are used for preamble tracking prior to the preamble channel estimation. \n
			:param mode: PAYLoad Payload tracking results are used for preamble tracking prior to the preamble channel estimation VHT (V) HT-LTF Symbols and Payload tracking results are used for preamble tracking prior to the preamble channel estimation.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PreambeTrackMode)
		self._core.io.write(f'SENSe:TRACking:PREamble {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PreambeTrackMode:
		"""SCPI: [SENSe]:TRACking:PREamble \n
		Snippet: value: enums.PreambeTrackMode = driver.applications.k91Wlan.sense.tracking.preamble.get() \n
		Defines which results are used for preamble tracking prior to the preamble channel estimation. \n
			:return: mode: PAYLoad Payload tracking results are used for preamble tracking prior to the preamble channel estimation VHT (V) HT-LTF Symbols and Payload tracking results are used for preamble tracking prior to the preamble channel estimation."""
		response = self._core.io.query_str(f'SENSe:TRACking:PREamble?')
		return Conversions.str_to_scalar_enum(response, enums.PreambeTrackMode)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EpdcchCls:
	"""Epdcch commands group definition. 5 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("epdcch", core, parent)

	@property
	def localized(self):
		"""localized commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_localized'):
			from .Localized import LocalizedCls
			self._localized = LocalizedCls(self._core, self._cmd_group)
		return self._localized

	@property
	def nprb(self):
		"""nprb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nprb'):
			from .Nprb import NprbCls
			self._nprb = NprbCls(self._core, self._cmd_group)
		return self._nprb

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def rbassign(self):
		"""rbassign commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbassign'):
			from .Rbassign import RbassignCls
			self._rbassign = RbassignCls(self._core, self._cmd_group)
		return self._rbassign

	@property
	def sid(self):
		"""sid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sid'):
			from .Sid import SidCls
			self._sid = SidCls(self._core, self._cmd_group)
		return self._sid

	def clone(self) -> 'EpdcchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EpdcchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlotCls:
	"""Slot commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slot", core, parent)

	def set(self, slot: float) -> None:
		"""SCPI: [SENSe]:NR5G:FRAMe:SLOT \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.frame.slot.set(slot = 1.0) \n
		This command defines the number of slots that are analyzed. \n
			:param slot: ALL Analyzes all slots in a frame. numeric value (integer only) Analyzes a certain number of slots in a frame.
		"""
		param = Conversions.decimal_value_to_str(slot)
		self._core.io.write(f'SENSe:NR5G:FRAMe:SLOT {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:NR5G:FRAMe:SLOT \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.nr5G.frame.slot.get() \n
		This command defines the number of slots that are analyzed. \n
			:return: slot: No help available"""
		response = self._core.io.query_str(f'SENSe:NR5G:FRAMe:SLOT?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:SFSummary:ALL \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.sfSummary.all.get() \n
		Returns the numeric results of the 'Spectrum Flatness' trace. This command is only available for the IEEE 802.11ax, be
		standards. For details see 'Spectrum Flatness Result Summary'. \n
			:return: result: SC_Start_No,SC_End_No,MinDist_Low,SC_MinDist_Low,MinDist_Up,SC_MinDist_Up,LimitCheckResult,... Comma-separated list of values for the overall subcarrier range and each subrange."""
		response = self._core.io.query_str(f'FETCh:SFSummary:ALL?')
		return trim_str_response(response)
